==> huaweicloudsdkkafka-3.1.151-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/update_topic_access_policy_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateTopicAccessPolicyReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'topics': 'list[AccessPolicyTopicEntity]'
    }

    attribute_map = {
        'topics': 'topics'
    }

    def __init__(self, topics=None):
        r"""UpdateTopicAccessPolicyReq

        The model defined in huaweicloud sdk

        :param topics: topic列表。
        :type topics: list[:class:`huaweicloudsdkkafka.v2.AccessPolicyTopicEntity`]
        """
        
        

        self._topics = None
        self.discriminator = None

        self.topics = topics

    @property
    def topics(self):
        r"""Gets the topics of this UpdateTopicAccessPolicyReq.

        topic列表。

        :return: The topics of this UpdateTopicAccessPolicyReq.
        :rtype: list[:class:`huaweicloudsdkkafka.v2.AccessPolicyTopicEntity`]
        """
        return self._topics

    @topics.setter
    def topics(self, topics):
        r"""Sets the topics of this UpdateTopicAccessPolicyReq.

        topic列表。

        :param topics: The topics of this UpdateTopicAccessPolicyReq.
        :type topics: list[:class:`huaweicloudsdkkafka.v2.AccessPolicyTopicEntity`]
        """
        self._topics = topics

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateTopicAccessPolicyReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkkafka-3.1.154-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/update_topic_access_policy_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateTopicAccessPolicyReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'topics': 'list[AccessPolicyTopicEntity]'
    }

    attribute_map = {
        'topics': 'topics'
    }

    def __init__(self, topics=None):
        r"""UpdateTopicAccessPolicyReq

        The model defined in huaweicloud sdk

        :param topics: Topic列表。
        :type topics: list[:class:`huaweicloudsdkkafka.v2.AccessPolicyTopicEntity`]
        """
        
        

        self._topics = None
        self.discriminator = None

        self.topics = topics

    @property
    def topics(self):
        r"""Gets the topics of this UpdateTopicAccessPolicyReq.

        Topic列表。

        :return: The topics of this UpdateTopicAccessPolicyReq.
        :rtype: list[:class:`huaweicloudsdkkafka.v2.AccessPolicyTopicEntity`]
        """
        return self._topics

    @topics.setter
    def topics(self, topics):
        r"""Sets the topics of this UpdateTopicAccessPolicyReq.

        Topic列表。

        :param topics: The topics of this UpdateTopicAccessPolicyReq.
        :type topics: list[:class:`huaweicloudsdkkafka.v2.AccessPolicyTopicEntity`]
        """
        self._topics = topics

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateTopicAccessPolicyReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
